@@ -1,5 +1,15 @@
 import dataclasses
-from typing import Any, ClassVar, Generic, List, Optional, Tuple, Type, Union
+from typing import (
+    Any,
+    AsyncGenerator,
+    ClassVar,
+    Generic,
+    List,
+    Optional,
+    Tuple,
+    Type,
+    Union,
+)
 
 from dbdaora.entity import Entity, EntityData
 from dbdaora.exceptions import RequiredKeyAttributeError
@@ -22,21 +32,26 @@ class BaseQuery(Generic[Entity, EntityData, FallbackKey]):
         self.memory = memory
 
     def make_key_parts(self, *args: Any, **kwargs: Any) -> List[Any]:
-        missed_key_attrs = []
-        key_parts = [
-            args[i] if i < len(args) else missed_key_attrs.append((i, key_attr))  # type: ignore
-            for i, key_attr in enumerate(self.repository.key_attrs)
-        ]
+        key_parts = []
+        args_counter = 0
 
-        try:
-            for i, attr_name in missed_key_attrs:
-                key_parts[i] = kwargs[attr_name]
-        except KeyError:
-            raise RequiredKeyAttributeError(
-                type(self.repository).__name__,
-                attr_name,
-                self.repository.key_attrs,
-            )
+        for key_attr_name in self.repository.key_attrs:
+
+            if key_attr_name in kwargs:
+                key_value = kwargs[key_attr_name]
+            else:
+                try:
+                    key_value = args[args_counter]
+                except IndexError:
+                    raise RequiredKeyAttributeError(
+                        type(self.repository).__name__,
+                        key_attr_name,
+                        self.repository.key_attrs,
+                    )
+
+                args_counter += 1
+
+            key_parts.append(key_value)
 
         return key_parts
 
@@ -45,7 +60,7 @@ class BaseQuery(Generic[Entity, EntityData, FallbackKey]):
         raise NotImplementedError()  # pragma: no cover
 
     @property
-    async def entities(self) -> List[Entity]:
+    def entities(self) -> AsyncGenerator[Entity, None]:
         raise NotImplementedError()  # pragma: no cover
 
     @property
@@ -68,17 +83,13 @@ class Query(BaseQuery[Entity, EntityData, FallbackKey]):
         key_parts: Optional[List[Any]] = None,
         **kwargs: Any,
     ):
-        self.repository = repository
-        self.memory = memory
+        super().__init__(repository, memory=memory)
 
         if key_parts:
             self.key_parts = key_parts
         else:
             self.key_parts = self.make_key_parts(*args, **kwargs)
 
-    def attribute_from_key(self, attr_name: str) -> Any:
-        return self.key_parts[self.repository.key_attrs.index(attr_name)]
-
     @property
     async def delete(self) -> None:
         await self.repository.delete(self)
@@ -149,8 +160,8 @@ class QueryMany(BaseQuery[Entity, EntityData, FallbackKey]):
         ]
 
     @property
-    async def entities(self) -> List[Entity]:
-        return await self.repository.entities(self)
+    def entities(self) -> AsyncGenerator[Entity, None]:
+        return self.repository.entities(self)
 
 
 def make(
